Low-level implementation of argument handling. Takes care of distinctions between flags and positionals, that sort of thing. No type handling happens here. Usually this is too low level to use directly.
Structs
- Arg
- A single, raw argument passed in from the command line.
- Arguments
Parser - An
ArgumentsParseris the main entry point intodebate_parser. It parses arguments in each call tonext_arg, sending those arguments to the givenVisitor. It handles distinguishing flags, options, and positionals; logic related to how flags get their argument values, and the--
Traits
- ArgAccess
ArgAccessallows a visitor to decide if a given parameter needs an argument, based on the identity of the parameter.- AsBytes
- Basically the same as
AsRef<u8>, but we want it for OsString and OsStr, too. - Visitor
- The
ArgumentsParsertype operates by passing arguments it finds into aVisitor, to be handled.